from django.db import models
from django.conf import settings
from sorl.thumbnail import ImageField
from django.db.models.signals import pre_save
from django.urls import reverse
from leaf.utils import unique_slug_generator
from django.template.defaultfilters import slugify

from autoslug import AutoSlugField
class Almacen(models.Model):
    name1 = models.CharField(max_length=16, help_text = "Nombre del Sitioweb")
    emblema_corto = models.CharField(max_length=22, blank=True, null=True, help_text = "Distintivo de su Sitioweb")
    emblema_largo = models.CharField(max_length=64, blank=True, null=True, help_text = "Título de su Sitioweb")
    slug = models.SlugField(unique=True, blank=True, null=False)
    city = models.CharField(max_length=32, blank=True, null=True)
    state = models.CharField(max_length=32, blank=True, null=True)
    country = models.CharField(max_length=32, blank=True, null=True)
    address = models.CharField(max_length=22, help_text = "Dirección como google-maps la identificaría")
    zipcode = models.CharField(max_length=32, blank=True, null=True)
    phone1 = models.CharField(max_length=12, blank=True, null=True, help_text = "Número Telefónico de Whatsapp")
    phone2 = models.CharField(max_length=12, help_text = "Otro teléfono")
    correo = models.EmailField(max_length=30, help_text = "Su email")                               # ==> contact
    image = models.ImageField(upload_to='vis9/web/sitio', help_text = "Foto principal del sitio", null=False, blank=False)    
    uploaded_at = models.DateTimeField(auto_now_add=True)
    image_description = models.CharField(max_length=38, blank=True, null=True)
    logo = models.ImageField(upload_to='vis9/web/logo', blank=True, null=True, help_text = "Logo del sitio")
    image_homepage = models.ImageField(upload_to='vis9/web/homepage', help_text = "Foto para la página home", null=False, blank=False)
    summary = models.TextField(max_length=820, blank=True, null=True, help_text = "Texto largo de su Sitioweb")
    quien = models.TextField(max_length=820, blank=True, null=True, help_text = "Texto para About: Quienes somos")    # ==> about
    tube = models.CharField(max_length=16, blank=True, null=True, help_text = "Su identificación o parte final del link youtube")
    face = models.CharField(max_length=16, blank=True, null=True, help_text = "Su identificación o parte final del link facebook")
    insta = models.CharField(max_length=16, blank=True, null=True, help_text = "Su identificación o parte final del link instagram")
    twit = models.CharField(max_length=16, blank=True, null=True, help_text = "Su identificación o parte final del link twitter")

    def name(self):
        return self.name1

    def __str__(self):
        return self.name1

    def create_slug(name1): 
       slug = slugify(name1)
       qs = Almacen.objects.filter(slug=slug)
       exists = qs.exists()
       if exists:
           slug = "%s-%s" %(slug, qs.first().id)
       return slug

    def get_absolute_url(self):
        return f"vis9/{self.slug}/"
        return reverse("vis9:almacen", kwargs={"slug": self.slug})

    def save(self, *args, **kwargs):  
        if not self.slug:
            self.slug = slugify(self.name1)
        return super().save(*args, **kwargs)

def slug_save(sender, instance, *args, **kwargs):
        if not instance.slug:
            instance.slug = unique_slug_generator(instance, instance_name1, instance_slug)

pre_save.connect(slug_save, sender=Almacen)

class Pict1(models.Model): 
    title = models.CharField(max_length=22, blank=True, null=True)
    slug = models.SlugField(unique=True, blank=True, null=False)
    image_description = models.CharField(max_length=38, blank=True, null=True)
    summary = models.TextField(max_length=370, blank=True, null=False)
    image = models.ImageField(upload_to='vis9/web/pict1/')                     # uploaded to MEDIA_ROOT/vis9/web/pict1/
    uploaded_at = models.DateTimeField(auto_now_add=True)

    almacen = models.ForeignKey(Almacen, null=True, on_delete=models.CASCADE, related_name='vis9_almacen')

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return f"vis9/{self.slug}/"
        return reverse("vis9:pict1", kwargs={"slug": self.slug})

    def save(self, *args, **kwargs):  
        if not self.slug:
            self.slug = slugify(self.title)
        return super().save(*args, **kwargs)
